package com.zehong.system.mapper;

import java.util.List;
import java.util.Map;

import com.zehong.system.domain.TDetectorInfo;
import com.zehong.system.domain.TDetectorUser;
import com.zehong.system.domain.TDetectorUserCount;
import com.zehong.system.domain.vo.TDetectorUserInspectVo;
import com.zehong.system.domain.vo.TDetectorUserVO;

/**
 * 燃气用户Mapper接口
 *
 * @author zehong
 * @date 2022-02-07
 */
public interface TDetectorUserMapper
{
    /**
     * 查询燃气用户
     *
     * @param userId 燃气用户ID
     * @return 燃气用户
     */
    public TDetectorUser selectTDetectorUserById(Long userId);

    /**
     * 查询燃气用户统计信息
     *
     * @return 燃气用户
     */
    public List<TDetectorUserVO> countTDetectorUser(TDetectorUser tDetectorUser);

    /**
     * 查询燃气用户统计信息大屏界面 使用massMarks标注的方式
     * @param tDetectorUser
     * @return
     */
    public List<TDetectorUserVO> countTDetectorUserForMassMarks(TDetectorUser tDetectorUser);

    /**
     * 查询探测器报警用户
     *
     * @return map
     */
    public List<Map> getDetectorUserAlarmList();

    /**
     * 泽宏云推送查询燃气用户
     *
     * @param tDetectorUser 燃气用户
     * @return 燃气用户
     */
    public List<TDetectorUser> selectTDetectorUser(TDetectorUser tDetectorUser);

    /**
     * 查询燃气用户列表
     *
     * @param tDetectorUser 燃气用户
     * @return 燃气用户集合
     */
    public List<TDetectorUser> selectTDetectorUserList(TDetectorUser tDetectorUser);
    public List<TDetectorUser> selectTDetectorListstatus(TDetectorUser tDetectorUser);

    /**
     * 新增燃气用户
     *
     * @param tDetectorUser 燃气用户
     * @return 结果
     */
    public int insertTDetectorUser(TDetectorUser tDetectorUser);

    /**
     * 修改燃气用户
     *
     * @param tDetectorUser 燃气用户
     * @return 结果
     */
    public int updateTDetectorUser(TDetectorUser tDetectorUser);

    /**
     * 删除燃气用户
     *
     * @param userId 燃气用户ID
     * @return 结果
     */
    public int deleteTDetectorUserById(Long userId);

    /**
     * 批量删除燃气用户
     *
     * @param userIds 需要删除的数据ID
     * @return 结果
     */
    public int deleteTDetectorUserByIds(Long[] userIds);

    /**
     * 查询用户数量
     * @return
     */
    public  Map<String,Object> selectUserNum();

    /**
     * 查询用户统计信息
     * @return
     */
    TDetectorUserCount userStatistics(String id);

    /**
     * 获取用户安检信息
     * @param inspectVo
     * @return
     */
    List<TDetectorUserInspectVo> getDetectorUserInspectInfo(TDetectorUserInspectVo inspectVo);
}
