package com.zehong.system.mapper;

import java.util.List;
import java.util.Map;

import com.zehong.system.domain.Statistics;
import com.zehong.system.domain.THiddenDangerStandingBook;
import com.zehong.system.domain.form.THiddenDangerStandingBookForm;
import com.zehong.system.domain.vo.THiddenDangerStandingBookVo;

/**
 * 隐患整治台账Mapper接口
 *
 * @author zehong
 * @date 2022-02-09
 */
public interface THiddenDangerStandingBookMapper
{
    /**
     * 查询隐患整治台账
     *
     * @param hiddenId 隐患整治台账ID
     * @return 隐患整治台账
     */
    public THiddenDangerStandingBook selectTHiddenDangerStandingBookById(Long hiddenId);

    /**
     * 查询隐患整治台账列表
     *
     * @param tHiddenDangerStandingBook 隐患整治台账
     * @return 隐患整治台账集合
     */
    public List<THiddenDangerStandingBook> selectTHiddenDangerStandingBookList(THiddenDangerStandingBookForm tHiddenDangerStandingBook);

    /**
     *  隐患台账统计
     *
     * @return 隐患整治台账集合
     */
    public THiddenDangerStandingBookVo selectTHiddenDangerStandingBookStatistic();

    /**
     * 新增隐患整治台账
     *
     * @param tHiddenDangerStandingBook 隐患整治台账
     * @return 结果
     */
    public int insertTHiddenDangerStandingBook(THiddenDangerStandingBook tHiddenDangerStandingBook);

    /**
     * 修改隐患整治台账
     *
     * @param tHiddenDangerStandingBook 隐患整治台账
     * @return 结果
     */
    public int updateTHiddenDangerStandingBook(THiddenDangerStandingBook tHiddenDangerStandingBook);

    /**
     * 删除隐患整治台账
     *
     * @param hiddenId 隐患整治台账ID
     * @return 结果
     */
    public int deleteTHiddenDangerStandingBookById(Long hiddenId);

    /**
     * 批量删除隐患整治台账
     *
     * @param hiddenIds 需要删除的数据ID
     * @return 结果
     */
    public int deleteTHiddenDangerStandingBookByIds(Long[] hiddenIds);

    /**
     * 获取隐患整治台账统计信息
     * @param sevenDate
     * @return
     */
    List<Statistics> hazardStatistics(List<String> sevenDate);

    /**
     * 统计每个月隐患已完成未完成数量
     * @return
     */
    List<Map<String,Object>> selectCountByMonth();
    /**
     * 统计每年隐患数量
     * @return
     */
    List<Map<String,Object>> selectCountByYear();
    /**
     * 根据乡镇统计隐患数量
     * @return
     */
    List<Map<String,Object>> selectHiddenRanking();
    /**
     * 根据隐患来源统计隐患数量
     * @return
     */
    List<Map<String,Object>> selectHiddenSource();

    /**
     * 隐患统计
     * @return
     */
    Map<String,Integer> hiddenBookStatistics();

}
